@@ -1,6 +1,6 @@
 import sys
 from dataclasses import dataclass
-from typing import Callable
+from typing import Callable, List
 from abc import ABC, abstractmethod
 
 from anipy_cli.misc import error, clear_console
@@ -20,7 +20,7 @@ class MenuOption:
 class MenuBase(ABC):
     @property
     @abstractmethod
-    def menu_options(self) -> list[MenuOption]:
+    def menu_options(self) -> List[MenuOption]:
         pass
 
     @abstractmethod
@@ -34,11 +34,7 @@ class MenuBase(ABC):
     def take_input(self):
         while True:
             picked = input("Enter option: ")
-            op = next(
-                filter(
-                    lambda x: x.trigger == picked, self.menu_options
-                ), None
-            )
+            op = next(filter(lambda x: x.trigger == picked, self.menu_options), None)
 
             if op is None:
                 error("invalid input")
@@ -54,5 +50,3 @@ class MenuBase(ABC):
 
     def quit(self):
         sys.exit()
-
-
