@@ -1,4 +1,5 @@
 import sys
+from typing import List
 
 from anipy_cli.arg_parser import CliArgs
 from anipy_cli.colors import colors, cprint
@@ -12,14 +13,16 @@ from anipy_cli.cli.menus.base_menu import MenuBase, MenuOption
 
 
 class Menu(MenuBase):
-    def __init__(self, options: CliArgs, entry: Entry, player: PlayerBaseType, rpc_client=None):
+    def __init__(
+        self, options: CliArgs, entry: Entry, player: PlayerBaseType, rpc_client=None
+    ):
         self.rpc_client = rpc_client
         self.options = options
         self.entry = entry
         self.player = player
 
     @property
-    def menu_options(self) -> list[MenuOption]:
+    def menu_options(self) -> List[MenuOption]:
         return [
             MenuOption("Next Episode",      self.next_ep,        "n"),
             MenuOption("Previous Episode",  self.prev_ep,        "p"),
@@ -32,10 +35,12 @@ class Menu(MenuBase):
         ]
 
     def print_header(self):
-        cprint(colors.GREEN,
-               f"Playing: {self.entry.show_name} {self.entry.quality} | ",
-               colors.RED,
-               f"{self.entry.ep}/{self.entry.latest_ep}")
+        cprint(
+            colors.GREEN,
+            f"Playing: {self.entry.show_name} {self.entry.quality} | ",
+            colors.RED,
+            f"{self.entry.ep}/{self.entry.latest_ep}",
+        )
 
     def start_ep(self):
         self.entry.embed_url = ""
